
#' Explore and Visualize Your Data Interactively
#'
#' A 'shiny' gadget to create 'ggplot2' figures interactively with drag-and-drop to map your variables to different aesthetics.
#' You can quickly visualize your data accordingly to their type, export in various formats,
#' and retrieve the code to reproduce the plot.
#'
#' @name esquisse
#' @author Fanny Meyer & Victor Perrier (@@dreamRs_fr)
#'
#' @examples
#' \dontrun{
#'
#' esquisser()
#'
#' # launch esquisse with specific data:
#' esquisser(mtcars)
#'
#' }
"_PACKAGE"


#' esquisse exported operators and S3 methods
#'
#'
#' @name esquisse-exports
NULL

#' @importFrom datamods i18n
#' @name i18n
#' @export
#' @rdname esquisse-exports
NULL

#' @importFrom datamods set_i18n
#' @name set_i18n
#' @export
#' @rdname esquisse-exports
NULL

#' @importFrom phosphoricons ph
#' @name ph
#' @export
#' @rdname esquisse-exports
NULL
